Class: Dommy::HTMLButtonElement

Inherits:
HTMLElement show all
Includes:
SubmitButtonActivation
Defined in:
lib/dommy/html_elements.rb

Overview

<button> — type defaults to "submit" per spec.

Constant Summary

Constants inherited from Element

Element::ADJACENT_POSITIONS, Element::APPROX_CHAR_PX, Element::APPROX_LINE_PX, Element::ATTRIBUTE_NODE, Element::CDATA_SECTION_NODE, Element::COMMENT_NODE, Element::DOCUMENT_FRAGMENT_NODE, Element::DOCUMENT_NODE, Element::DOCUMENT_POSITION_CONTAINED_BY, Element::DOCUMENT_POSITION_CONTAINS, Element::DOCUMENT_POSITION_DISCONNECTED, Element::DOCUMENT_POSITION_FOLLOWING, Element::DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC, Element::DOCUMENT_POSITION_PRECEDING, Element::DOCUMENT_TYPE_NODE, Element::ELEMENT_NODE, Element::HTML_NAMESPACE, Element::INLINE_TAGS, Element::PROCESSING_INSTRUCTION_NODE, Element::REFLECTED_TOKEN_LIST_HOSTS, Element::SHADOW_HOST_TAGS, Element::SVG_NAMESPACE, Element::TEXT_NODE

Constants included from Node

Node::ATTRIBUTE_NODE, Node::CDATA_SECTION_NODE, Node::COMMENT_NODE, Node::DOCUMENT_FRAGMENT_NODE, Node::DOCUMENT_NODE, Node::DOCUMENT_POSITION_CONTAINED_BY, Node::DOCUMENT_POSITION_CONTAINS, Node::DOCUMENT_POSITION_DISCONNECTED, Node::DOCUMENT_POSITION_FOLLOWING, Node::DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC, Node::DOCUMENT_POSITION_PRECEDING, Node::DOCUMENT_TYPE_NODE, Node::ELEMENT_NODE, Node::HTML_NAMESPACE, Node::PROCESSING_INSTRUCTION_NODE, Node::TEXT_NODE, Node::XMLNS_NAMESPACE, Node::XML_NAMESPACE

Instance Attribute Summary

Attributes inherited from Element

#document

Instance Method Summary collapse

Methods included from SubmitButtonActivation

#activation_behavior, #activation_target?

Methods inherited from HTMLElement

#case_sensitive_attribute_names?, #disabled_by_ancestor_fieldset?, #labels_node_list, #parse_non_negative_reflected, #set_non_negative_reflected

Methods included from Internal::ReflectedAttributes

included

Methods inherited from Element

#[], #[]=, #__dommy_backend_node__, #__internal_approx_box, #__internal_case_sensitive_attribute_names__?, #__internal_created_namespace__, #__internal_normalize_attr_key__, #__internal_set_namespace__, #__internal_shadow_root__, #__js_attribute_snapshot__, #__run_click_activation_behavior__, #__test_scroll_log__, #access_key_label, #accessibility_tree, #activation_behavior, #activation_target, #activation_target?, #after, #anchor_href, #animate, #approximate_layout?, #aria_content_attr, #aria_element_attr, #aria_element_get, #aria_element_set, #aria_elements_attr, #aria_elements_current, #aria_elements_get, #aria_elements_set, #aria_find_in_root, #aria_get, #aria_ref_in_valid_scope?, #aria_set, #aria_snapshot, #assigned_slot, #at_xpath, #attach_shadow, #attributes, #base_uri, #before, #blur, #child_element_count, #child_nodes, #children, #class_list, #class_name, #class_name=, #clear_aria_element_ref_for, #click, #clone_node, #closest, #computed_description, #computed_label, #computed_role, #contains?, #dataset, #element_prefix, #equal_node?, #first_child, #first_element_child, #focus, #get_animations, #get_attribute, #get_attribute_names, #get_attribute_node, #get_attribute_node_ns, #get_attribute_ns, #get_bounding_client_rect, #get_client_rects, #get_elements_by_class_name, #get_elements_by_tag_name, #get_elements_by_tag_name_ns, #get_html, #get_inner_html, #has_attribute?, #has_attribute_ns?, #has_attributes?, #has_child_nodes?, #hide_popover, #id, #id=, #initialize, #inner_html, #inner_html=, #insert_adjacent_element, #insert_adjacent_html, #insert_adjacent_text, #insert_before, #insertion_parent!, #is_connected?, #last_child, #last_element_child, #live_child_nodes, #local_name, #mark_fragment_scripts_started, #matches?, #namespace_uri, #next_element_sibling, #next_sibling, #on, #outer_html, #outer_html=, #owner_document, #parent_element, #parent_node, #path, #pre_click_activation_state, #previous_element_sibling, #previous_sibling, #query_selector, #query_selector_all, #reflected_attr_name, #reflected_token_list, #remove, #remove_attribute, #remove_attribute_node, #remove_attribute_ns, #remove_child, #replace_child, #replace_with_nodes, #request_fullscreen, #restore_pre_click_activation, #role, #role=, #root_node, #run_post_click_activation, #same_node?, #set_attribute, #set_attribute_node, #set_attribute_ns, #shadow_root, #show_popover, #slot, #slot=, #style, #tag_name, #text_content, #text_content=, #to_s, #toggle_attribute, #toggle_popover, #translate_mode?, #validate_adjacent_document_insert!, #with_selector_errors, #xpath

Methods included from Bridge::Methods

included

Methods included from Internal::ParentNode

#append, #append_child, #normalize, #prepend, #replace_children

Methods included from Internal::ChildNode

#child_node_after, #child_node_before, #child_node_replace_with, #nullable_dom_string, #validate_insert_before_ref!

Methods included from Node

#compare_document_position, #get_root_node, #is_default_namespace, #is_equal_node, #is_same_node, #lookup_namespace_uri, #lookup_prefix

Methods included from EventTarget

#__dommy_dump_event_failure__, #__internal_deliver_event__, #__internal_event_parent__, #__internal_process_event_handler_return__, #add_event_listener, capture_flag, #deliver_at, #dispatch_event, #event_name_from_on, #invoke_listener_isolated, js_truthy?, #on_handler, #remove_event_listener, #set_on_handler

Constructor Details

This class inherits a constructor from Dommy::Element

Instance Method Details

#__js_call__(method, args) ⇒ Object



1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/dommy/html_elements.rb', line 1446

def __js_call__(method, args)
  case method
  when "checkValidity"
    check_validity
  when "reportValidity"
    report_validity
  when "setCustomValidity"
    set_custom_validity(args[0])
  else
    super
  end
end

#__js_get__(key) ⇒ Object



1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/dommy/html_elements.rb', line 1417

def __js_get__(key)
  case key
  when "type"
    type
  when "form"
    form
  when "labels"
    labels
  when "validity"
    validity
  when "willValidate"
    will_validate
  when "validationMessage"
    validation_message
  else
    super
  end
end

#__js_set__(key, value) ⇒ Object



1436
1437
1438
1439
1440
1441
1442
1443
# File 'lib/dommy/html_elements.rb', line 1436

def __js_set__(key, value)
  case key
  when "type"
    set_reflected_string("type", value)
  else
    super
  end
end

#__submit_button__?Boolean

Returns:

  • (Boolean)


1367
# File 'lib/dommy/html_elements.rb', line 1367

def __submit_button__? = type == "submit" && !disabled

#check_validityObject



1404
1405
1406
# File 'lib/dommy/html_elements.rb', line 1404

def check_validity
  true
end

#formObject

The form owner: a form= attribute pointing at a form (form-associated element, so a button can live outside its form), else the nearest ancestor form. Mirrors HTMLInputElement#form_owner.



1376
1377
1378
1379
1380
1381
1382
1383
1384
# File 'lib/dommy/html_elements.rb', line 1376

def form
  form_id = get_attribute("form").to_s
  unless form_id.empty?
    target = @document.get_element_by_id(form_id)
    return (target && target.tag_name.to_s.casecmp?("form")) ? target : nil
  end

  closest("form")
end

#labelsObject



1386
1387
1388
# File 'lib/dommy/html_elements.rb', line 1386

def labels
  labels_node_list
end

#report_validityObject



1408
1409
1410
# File 'lib/dommy/html_elements.rb', line 1408

def report_validity
  true
end

#set_custom_validity(msg) ⇒ Object



1412
1413
1414
1415
# File 'lib/dommy/html_elements.rb', line 1412

def set_custom_validity(msg)
  @custom_validity_message = msg.to_s
  nil
end

#typeObject



1362
1363
1364
1365
# File 'lib/dommy/html_elements.rb', line 1362

def type
  raw = @__node__["type"].to_s.downcase
  %w[submit reset button].include?(raw) ? raw : "submit"
end

#type=(v) ⇒ Object



1369
1370
1371
# File 'lib/dommy/html_elements.rb', line 1369

def type=(v)
  set_reflected_string("type", v)
end

#validation_messageObject



1400
1401
1402
# File 'lib/dommy/html_elements.rb', line 1400

def validation_message
  ""
end

#validityObject



1390
1391
1392
# File 'lib/dommy/html_elements.rb', line 1390

def validity
  @__validity ||= ValidityState.new(self)
end

#will_validateObject

Only a submit button is a candidate for constraint validation; reset / button types are barred, as are disabled controls and datalist descendants.



1396
1397
1398
# File 'lib/dommy/html_elements.rb', line 1396

def will_validate
  type == "submit" && !disabled && !disabled_by_ancestor_fieldset? && closest("datalist").nil?
end