Class: Dommy::Internal::CSS::Parser::ScopeRule

Inherits:
Struct
  • Object
show all
Defined in:
lib/dommy/internal/css/parser.rb

Overview

(either may be nil: a missing start scopes to the document element, a missing end has no lower boundary). RuleIndex resolves the scoping roots and limits and scopes the block's rules to in-scope elements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#endObject

Returns the value of attribute end

Returns:

  • (Object)

    the current value of end



60
61
62
# File 'lib/dommy/internal/css/parser.rb', line 60

def end
  @end
end

#rulesObject

Returns the value of attribute rules

Returns:

  • (Object)

    the current value of rules



60
61
62
# File 'lib/dommy/internal/css/parser.rb', line 60

def rules
  @rules
end

#startObject

Returns the value of attribute start

Returns:

  • (Object)

    the current value of start



60
61
62
# File 'lib/dommy/internal/css/parser.rb', line 60

def start
  @start
end

Instance Method Details

#grouping?Boolean

Returns:

  • (Boolean)


61
# File 'lib/dommy/internal/css/parser.rb', line 61

def grouping? = true