Class: Dommy::Internal::CSS::RuleIndex::Scope
- Inherits:
-
Struct
- Object
- Struct
- Dommy::Internal::CSS::RuleIndex::Scope
- Defined in:
- lib/dommy/internal/css/rule_index.rb
Overview
A resolved @scope: the scoping roots that scope-start matched, and the per-root scope limits (boundary elements from scope-end). An element is in scope for a root when it is an inclusive descendant of that root and not an inclusive descendant of any of the root's limits.
Instance Attribute Summary collapse
-
#ends ⇒ Object
Returns the value of attribute ends.
-
#roots ⇒ Object
Returns the value of attribute roots.
Instance Attribute Details
#ends ⇒ Object
Returns the value of attribute ends
25 26 27 |
# File 'lib/dommy/internal/css/rule_index.rb', line 25 def ends @ends end |
#roots ⇒ Object
Returns the value of attribute roots
25 26 27 |
# File 'lib/dommy/internal/css/rule_index.rb', line 25 def roots @roots end |